@@ -70,8 +70,8 @@ class HostsEntry(object):
         return self.entry_type in ('ipv4', 'ipv6')
 
     def __repr__(self):
-        return "HostsEntry(entry_type=\'{0}\', address=\'{1}\', " \
-               "names={2}, comment=\'{3}\')".format(
+        return "HostsEntry(entry_type={0!r}, address={1!r}, " \
+               "names={2!r}, comment={3!r})".format(
                    self.entry_type,
                    self.address,
                    self.names,
@@ -140,9 +140,9 @@ class HostsEntry(object):
 
 class Hosts(object):
     """ A hosts file. """
-    __slots__ = ['entries', 'hosts_path']
+    __slots__ = ['path','entries']
 
-    def __init__(self, path=None):
+    def __init__(self, path=None, entries=None):
         """
         Initialise an instance of a hosts file
         :param path: The filesystem path of the hosts file to manage
@@ -151,18 +151,24 @@ class Hosts(object):
 
         self.entries = []
         if path:
-            self.hosts_path = path
+            self.path = path
         else:
-            self.hosts_path = self.determine_hosts_path()
-        self.populate_entries()
+            self.path = self.determine_hosts_path()
+
+        if entries:
+            self.entries = entries
+        else:
+            self.populate_entries()
 
     def __repr__(self):
-        return 'Hosts(hosts_path=\'{0}\', entries={1})'.format(self.hosts_path, self.entries)
+        return 'Hosts(path=\'{0}\', entries={1!r})'.format(
+            self.path, self.entries
+        )
 
     def __str__(self):
-        output = ('hosts_path={0}, '.format(self.hosts_path))
+        output = ('PATH:{0}\n'.format(self.path))
         for entry in self.entries:
-            output += str(entry)
+            output += str(entry) + "\n"
         return output
 
     def count(self):
@@ -201,7 +207,7 @@ class Hosts(object):
         if path:
             output_file_path = path
         else:
-            output_file_path = self.hosts_path
+            output_file_path = self.path
         try:
             with open(output_file_path, mode) as hosts_file:
                 for written_count, line in enumerate(self.entries):
@@ -229,7 +235,7 @@ class Hosts(object):
                             )
                         )
                         ipv6_entries_written += 1
-        except:
+        except Exception:
             raise UnableToWriteHosts()
         return {'total_written': written_count + 1,
                 'comments_written': comments_written,
@@ -249,11 +255,13 @@ class Hosts(object):
 
     def exists(self, address=None, names=None, comment=None):
         """
-        Determine if the supplied address and/or names, or comment, exists in a HostsEntry within Hosts
+        Determine if the supplied address and/or names, or comment, exists in
+         a HostsEntry within Hosts
         :param address: An ipv4 or ipv6 address to search for
         :param names: A list of names to search for
         :param comment: A comment to search for
-        :return: True if a supplied address, name, or comment is found. Otherwise, False.
+        :return: True if a supplied address, name, or comment is found.
+            Otherwise, False.
         """
         for name in (names or [None]):
             if self.find_all_matching(address=address, name=name, comment=comment):
@@ -290,7 +298,7 @@ class Hosts(object):
     def find_all_matching(self, address=None, name=None, comment=None):
         """
         Return all HostsEntry instances from the Hosts object
-        where the supplied ip address or name matches
+          where the supplied ip address or name matches
         :param address: An ipv4 or ipv6 address
         :param name: A host name
         :param comment: A host inline comment
@@ -315,8 +323,8 @@ class Hosts(object):
 
     def import_url(self, url=None, force=None):
         """
-        Read a list of host entries from a URL, convert them into instances of HostsEntry and
-        then append to the list of entries in Hosts
+        Read a list of host entries from a URL, convert them into instances
+          of HostsEntry and then append to the list of entries in Hosts
         :param url: The URL of where to download a hosts file
         :return: Counts reflecting the attempted additions
         """
@@ -378,12 +386,14 @@ class Hosts(object):
             return {'result': 'failed',
                     'message': 'Cannot read: file {0}.'.format(import_file_path)}
 
-    def add(self, entries=None, force=False, allow_address_duplication=False, merge_names=False):
+    def add(self, entries=None, force=False, allow_address_duplication=False,
+            merge_names=False):
         """
         Add instances of HostsEntry to the instance of Hosts.
         :param entries: A list of instances of HostsEntry
         :param force: Remove matching before adding
-        :param allow_address_duplication: Allow using multiple entries for same address
+        :param allow_address_duplication: Allow using multiple entries
+         for same address
         :param merge_names: Merge names where address already exists
         :return: The counts of successes and failures
         """
@@ -468,12 +478,13 @@ class Hosts(object):
 
     def populate_entries(self):
         """
-        Called by the initialiser of Hosts. This reads the entries from the local hosts file,
-        converts them into instances of HostsEntry and adds them to the Hosts list of entries.
+        Called by the initialiser of Hosts. This reads the entries from the
+         local hosts file, converts them into instances of HostsEntry and adds
+         them to the Hosts list of entries.
         :return: None
         """
         try:
-            with open(self.hosts_path, 'r') as hosts_file:
+            with open(self.path, 'r') as hosts_file:
                 hosts_entries = [line for line in hosts_file]
                 for hosts_entry in hosts_entries:
                     entry_type = HostsEntry.get_entry_type(hosts_entry)
@@ -490,7 +501,8 @@ class Hosts(object):
                         comment = None
                         if len(split_entry) == 2:
                             comment = split_entry[1].strip()
-                        stripped_name_list = [name.strip() for name in chunked_entry[1:]]
+                        stripped_name_list = [name.strip() for name in
+                                              chunked_entry[1:]]
 
                         self.entries.append(
                             HostsEntry(
@@ -500,4 +512,4 @@ class Hosts(object):
                                 comment=comment))
         except IOError:
             return {'result': 'failed',
-                    'message': 'Cannot read: {0}.'.format(self.hosts_path)}
+                    'message': 'Cannot read: {0}.'.format(self.path)}
